==> axiom-1.2.21-src.zip: axiom-1.2.21/buildutils/shade-axiom-xml/src/main/java/org/apache/axiom/buildutils/shade/axiomxml/DOMUtils.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.axiom.buildutils.shade.axiomxml;

import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;

import javax.xml.parsers.DocumentBuilderFactory;
import javax.xml.parsers.ParserConfigurationException;
import javax.xml.transform.TransformerException;
import javax.xml.transform.TransformerFactory;
import javax.xml.transform.dom.DOMSource;
import javax.xml.transform.stream.StreamResult;

import org.w3c.dom.Document;
import org.xml.sax.SAXException;

public final class DOMUtils {
    private DOMUtils() {}
    
    public static Document parse(InputStream is) throws IOException {
        try {
            DocumentBuilderFactory factory = DocumentBuilderFactory.newInstance();
            factory.setNamespaceAware(true);
            return factory.newDocumentBuilder().parse(is);
        } catch (SAXException ex) {
            throw toIOException(ex);
        } catch (ParserConfigurationException ex) {
            throw toIOException(ex);
        }
    }
    
    public static void serialize(Document document, OutputStream os) throws IOException {
        try {
            TransformerFactory.newInstance().newTransformer().transform(new DOMSource(document), new StreamResult(os));
        } catch (TransformerException ex) {
            throw toIOException(ex);
        }
    }

    private static IOException toIOException(Exception ex) {
        IOException ioException = new IOException();
        ioException.initCause(ex);
        return ioException;
    }
}

==> axiom-2.0.0-src.zip: axiom-2.0.0/buildutils/shade-axiom-xml/src/main/java/org/apache/axiom/buildutils/shade/axiomxml/DOMUtils.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.axiom.buildutils.shade.axiomxml;

import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;

import javax.xml.parsers.DocumentBuilderFactory;
import javax.xml.parsers.ParserConfigurationException;
import javax.xml.transform.TransformerException;
import javax.xml.transform.TransformerFactory;
import javax.xml.transform.dom.DOMSource;
import javax.xml.transform.stream.StreamResult;

import org.w3c.dom.Document;
import org.xml.sax.SAXException;

public final class DOMUtils {
    private DOMUtils() {}

    public static Document parse(InputStream is) throws IOException {
        try {
            DocumentBuilderFactory factory = DocumentBuilderFactory.newInstance();
            factory.setNamespaceAware(true);
            return factory.newDocumentBuilder().parse(is);
        } catch (SAXException ex) {
            throw toIOException(ex);
        } catch (ParserConfigurationException ex) {
            throw toIOException(ex);
        }
    }

    public static void serialize(Document document, OutputStream os) throws IOException {
        try {
            TransformerFactory.newInstance()
                    .newTransformer()
                    .transform(new DOMSource(document), new StreamResult(os));
        } catch (TransformerException ex) {
            throw toIOException(ex);
        }
    }

    private static IOException toIOException(Exception ex) {
        IOException ioException = new IOException();
        ioException.initCause(ex);
        return ioException;
    }
}
